---
title: <span class="badge object-type-scalar"></span> Humidity
---
# <span class="badge object-type-scalar"></span> Humidity

Humidity (%H)

## Definition

```python
# Humidity (%H)
Humidity: typing.Literal["humidity"] = "humidity"
```
